@@ -1,47 +1,3 @@
-# addin behaviour specifics
-MARS2list_Addin <- function() {
-  context   <- rstudioapi::getActiveDocumentContext()
-  selection <- context$selection[[1]]$text
-  request  <- MARS_to_list(selection)
-  location <- context$selection[[1]]$range
-  rstudioapi::modifyRange(location = location,
-                          text = request,
-                          id = context$id)
-}
-
-# conversion function to translate a MARS query into
-# a ecmwfr list statement
-MARS_to_list <- function(MARS_text) {
-
-  if(missing(MARS_text)){
-    stop("No input text provided")
-  }
-
-  MARS_text <- strsplit(MARS_text, "\n")[[1]]
-  MARS_text <- strsplit(MARS_text, "=")
-  MARS_text <- MARS_text[lengths(MARS_text) == 2]
-  max_chars <- max(vapply(MARS_text, function(t) nchar(t[1]), 1))
-  MARS_text  <- lapply(seq_along(MARS_text), function(t) {
-    text <- MARS_text[[t]]
-    if (length(text) != 2) {
-      return("")
-    }
-    last_char <- substr(text[2], nchar(text[2]), nchar(text[2]))
-    if (last_char == ",") {
-      text[2] <- strtrim(text[2], nchar(text[2]) - 1)
-    }
-
-    text[2] <- gsub('"', "", text[2])
-
-    text[1] <- formatC(text[1], width = -max_chars, flag = " ")
-    paste0("  ", text[1], ' = "', text[2], '"', sep = "")
-  })
-
-  return(paste0("request <- list(\n",
-                paste0(unlist(MARS_text), collapse = ",\n"),
-                "\n)"))
-}
-
 # addin behaviour specifics
 python2list_Addin <- function() {
   context   <- rstudioapi::getActiveDocumentContext()
@@ -61,12 +17,33 @@ python_to_list <- function(python_text) {
     stop("No input text provided")
   }
 
-  python_text <- gsub('\'','"',python_text)
+  # substitute inconsistent quotes, sorting the f-ing API mess
+  # for consistency
+  python_text <- gsub("\\\"","\'", python_text)
 
-  # grab anything between ()
-  brackets <- try(gsub("[\\(\\)]", "",
-                   regmatches(python_text,
-                              gregexpr("\\(.*?\\)", python_text))[[1]]))
+  # split string on line breaks
+  line_breaks <- strsplit(python_text, "\\n")[[1]]
+
+  leading <- line_breaks[grep("dataset", line_breaks)]
+  trailing <- line_breaks[grep("target", line_breaks)]
+
+  # clean up leading and trailing ends if any
+  if (nchar(leading) == 0 || length(leading) == 0){
+    stop("Incomplete query selection: dataset is missing")
+  }
+
+  # dropping field name and removing quotes
+  leading <- gsub("dataset = ","", leading)
+  leading <- gsub("\'","", leading)
+
+  # clean up leading and trailing ends if any
+  if (nchar(trailing) == 0 || length(trailing) == 0){
+    trailing <- "TMPFILE"
+  } else {
+    # dropping field name and removing quotes
+    trailing <- gsub("target = ","", trailing)
+    trailing <- gsub("\'","", trailing)
+  }
 
   # grab anything between {} within ()
   c_brackets <- try(gsub("[\\{\\}]", "",
@@ -74,7 +51,7 @@ python_to_list <- function(python_text) {
                                     gregexpr("\\{.*?\\}", python_text))[[1]]))
 
   # check if strings have content
-  if(length(brackets) == 0 || length(c_brackets) == 0){
+  if(length(c_brackets) == 0){
     stop("Incomplete query selection")
   }
 
@@ -86,26 +63,22 @@ python_to_list <- function(python_text) {
 
   # Remove trailing commas (",]")
   c_brackets <- gsub(",]", "]", c_brackets)
+  c_brackets <- paste0("{",c_brackets,"}")
+  c_brackets <- gsub("\'", "\"", c_brackets)
 
   # read in data as list
-  c_list <- jsonlite::fromJSON(paste0("{",c_brackets,"}"))
+  c_list <- jsonlite::fromJSON(c_brackets)
 
-  # grab the trailing bit between } and ) i.e. the dataste name
-  leading <- try(gsub("[\\(\\{]", "",
-                       regmatches(python_text,
-                                  gregexpr("\\(.*?\\{", python_text))[[1]]))
-
-  # grab the leading bit between ( and } i.e. the target
-  trailing <- try(gsub("[\\}\\)]", "",
-                       regmatches(python_text,
-                                  gregexpr("\\}.*?\\)", python_text))[[1]]))
+  # add leading and trailing bits
+  # to request list
+  c_list <- c(dataset_short_name = leading, c_list, target = trailing)
 
   # clean up leading and trailing ends if any
-  if (nchar(leading) != 0){
+  if (nchar(leading) == 0 || length(leading) == 0){
     c_list$dataset_short_name <- gsub('\\n|,\\n| |"','', leading)
   }
 
-  if (nchar(trailing) != 0){
+  if (nchar(trailing) == 0 || length(trailing) == 0){
     c_list$target <- gsub('\\n|,\\n| |"','', trailing)
   }
 
@@ -126,3 +99,4 @@ python_to_list <- function(python_text) {
              collapse = ",\n"),
            "\n)"))
 }
+
